@@ -687,4 +687,7 @@ def get_spark_schema(pdf):
         struct_list.append(StructField(col, spark_typ))
         
     spark_schema = StructType(struct_list)
-    return spark_schema
\ No newline at end of file
+    return spark_schema
+
+def test():
+    pass
\ No newline at end of file
